<?php

/**
 * @file
 * Provides admin form settongs for the module.
 */

/**
 * Module admin form.
 */
function _node_delete_redirect_admin_form() {
  $form = array();

  $options = array(
    0 => t('Disable'),
    1 => t('Enable'),
  );

  $form['ndr_check'] = array(
    '#type' => 'radios',
    '#title' => t('Node Delete Redirect'),
    '#default_value' => variable_get('ndr_check', 0),
    '#options' => $options,
    '#description' => t('When disabled, redirection rules will not apply.'),
    '#required' => TRUE,
  );

  $form['ndr_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Enable Redirect For Content Type'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#states' => array(
      'visible' => array(
        ':input[name=ndr_check]' => array(
          'value' => 1,
        ),
      ),
    ),
  );

  $content_types = node_type_get_types();
  foreach ($content_types as $keys => $values) {
    $ndr_is_enabled = isset(variable_get('ndr_settings', FALSE)['ctype_' . $keys]['is_enabled']) ? variable_get('ndr_settings', FALSE)['ctype_' . $keys]['is_enabled'] : '';
    $form['ndr_settings']['ctype_' . $keys]['is_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => check_plain($values->name),
      '#default_value' => $ndr_is_enabled,
    );

    $form['ndr_settings']['ctype_' . $keys]['redirect_' . $keys . '_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Redirect URL settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#parents' => array('ndr_settings', 'ctype_' . $keys),
      '#states' => array(
        'visible' => array(
          ':input[name=ndr_settings\[ctype_' . $keys . '\]\[is_enabled\]]' => array(
            'checked' => TRUE,
          ),
        ),
      ),
    );

    $ndr_redirect_settings = isset(variable_get('ndr_settings', '')['ctype_' . $keys]['redirect_' . $keys]) ? variable_get('ndr_settings', '')['ctype_' . $keys]['redirect_' . $keys] : '';
    $form['ndr_settings']['ctype_' . $keys]['redirect_' . $keys . '_settings']['redirect_' . $keys] = array(
      '#type' => 'textfield',
      '#title' => t('Redirect URL'),
      '#default_value' => $ndr_redirect_settings,
      '#description' => t('Example: node/123'),
      '#element_validate' => array('_node_delete_redirect_path_validate'),
      '#size' => 45,
      '#maxlength' => 128,
    );
  }

  return system_settings_form($form);
}

/**
 * Module form validate.
 */
function _node_delete_redirect_path_validate($element, &$form_state) {
  preg_match("/redirect_([a-z0-9_]+)\]$/", $element['#name'], $matches);
  $ctype = $matches[1];
  if (isset($form_state['values']['ndr_settings']['ctype_' . $ctype]['redirect_' . $ctype]) && $form_state['values']['ndr_settings']['ctype_' . $ctype]['redirect_' . $ctype]) {
    if (!trim($element['#value']) || !drupal_valid_path($element['#value'], TRUE)) {
      form_error($element, t("The path '@path' is either invalid or you do not have access to it.", array('@path' => $element['#value'])));
    }
  }
}
